#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['podcast_search']

package_data = \
{'': ['*']}

setup(name='podcast_search',
      version='0.1.0',
      description="Let's find some podcasts!",
      author='Jelmer Keuzenkamp',
      author_email=None,
      url='https://github.com/cryptojelmerkeuzenkamp',
      packages=packages,
      package_data=package_data,
     )
